import { Layout, LayoutItem, LayoutToType, DynamicItemsOfLayout } from "@wormhole-foundation/sdk-base";
declare global {
    namespace Wormhole {
        interface PayloadLiteralToLayoutMapping {
        }
    }
}
type LayoutLiteral = keyof Wormhole.PayloadLiteralToLayoutMapping & string;
type LayoutOf<LL extends LayoutLiteral> = LL extends infer V extends LayoutLiteral ? Wormhole.PayloadLiteralToLayoutMapping[V] : never;
type LayoutLiteralToPayloadType<LL extends LayoutLiteral> = LayoutToType<LayoutOf<LL>>;
export type PayloadLiteral = LayoutLiteral | "Uint8Array";
type PayloadLiteralToPayloadType<PL extends PayloadLiteral> = PL extends LayoutLiteral ? LayoutLiteralToPayloadType<PL> : Uint8Array;
declare const baseLayout: readonly [{
    readonly name: "version";
    readonly binary: "uint";
    readonly size: 1;
    readonly custom: 1;
    readonly omit: true;
}, {
    readonly binary: "uint";
    readonly size: 4;
    readonly name: "guardianSet";
}, {
    readonly name: "signatures";
    readonly binary: "array";
    readonly lengthSize: 1;
    readonly layout: readonly [{
        readonly name: "guardianIndex";
        readonly binary: "uint";
        readonly size: 1;
    }, {
        readonly binary: "bytes";
        readonly size: 65;
        readonly custom: {
            readonly to: (val: Uint8Array) => import("./signature").Signature;
            readonly from: (val: import("./signature").Signature) => Uint8Array;
        };
        readonly name: "signature";
    }];
}, {
    readonly name: "timestamp";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly name: "nonce";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly custom: {
        to: (val: number) => "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia";
        from: (val: "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia") => number;
    };
    readonly binary: "uint";
    readonly size: 2;
    readonly name: "emitterChain";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("./universalAddress").UniversalAddress;
        from: (val: import("./universalAddress").UniversalAddress) => Uint8Array;
    };
    readonly name: "emitterAddress";
}, {
    readonly binary: "uint";
    readonly size: 8;
    readonly name: "sequence";
}, {
    readonly name: "consistencyLevel";
    readonly binary: "uint";
    readonly size: 1;
}];
type BaseLayout = LayoutToType<typeof baseLayout>;
export interface VAA<PL extends PayloadLiteral = PayloadLiteral> extends BaseLayout {
    readonly payloadLiteral: PL;
    readonly payload: PayloadLiteralToPayloadType<PL>;
    readonly hash: Uint8Array;
}
type PayloadLiteralToDynamicItems<PL extends PayloadLiteral> = DynamicItemsOfLayout<[
    ...typeof baseLayout,
    PL extends LayoutLiteral ? {
        name: "payload";
        binary: "object";
        layout: DynamicItemsOfLayout<LayoutOf<PL>>;
    } : {
        name: "payload";
        binary: "bytes";
    }
]>;
export declare const create: <PL extends PayloadLiteral = "Uint8Array">(payloadLiteral: PL, vaaData: LayoutToType<readonly [{
    readonly binary: "uint";
    readonly size: 4;
    readonly name: "guardianSet";
}, {
    readonly name: "signatures";
    readonly binary: "array";
    readonly lengthSize: 1;
    readonly layout: readonly [{
        readonly name: "guardianIndex";
        readonly binary: "uint";
        readonly size: 1;
    }, {
        readonly binary: "bytes";
        readonly size: 65;
        readonly custom: {
            readonly to: (val: Uint8Array) => import("./signature").Signature;
            readonly from: (val: import("./signature").Signature) => Uint8Array;
        };
        readonly name: "signature";
    }];
}, {
    readonly name: "timestamp";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly name: "nonce";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly custom: {
        to: (val: number) => "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia";
        from: (val: "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia") => number;
    };
    readonly binary: "uint";
    readonly size: 2;
    readonly name: "emitterChain";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("./universalAddress").UniversalAddress;
        from: (val: import("./universalAddress").UniversalAddress) => Uint8Array;
    };
    readonly name: "emitterAddress";
}, {
    readonly binary: "uint";
    readonly size: 8;
    readonly name: "sequence";
}, {
    readonly name: "consistencyLevel";
    readonly binary: "uint";
    readonly size: 1;
}, ...[(PL extends LayoutLiteral ? {
    name: "payload";
    binary: "object";
    layout: DynamicItemsOfLayout<LayoutOf<PL>>;
} : {
    name: "payload";
    binary: "bytes";
}) extends infer T ? T extends (PL extends LayoutLiteral ? {
    name: "payload";
    binary: "object";
    layout: DynamicItemsOfLayout<LayoutOf<PL>>;
} : {
    name: "payload";
    binary: "bytes";
}) ? T extends {
    custom: import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType | import("@wormhole-foundation/sdk-base").FixedConversion<import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType, any>;
} ? never : T extends import("@wormhole-foundation/sdk-base").ArrayLayoutItem | import("@wormhole-foundation/sdk-base").ObjectLayoutItem ? DynamicItemsOfLayout<T["layout"]> extends readonly LayoutItem[] ? [DynamicItemsOfLayout<T["layout"]>[number]] extends [never] ? never : { readonly [K in keyof T]: K extends "layout" ? DynamicItemsOfLayout<T["layout"]> : T[K]; } : never : T : never : never] extends [never] ? readonly [] : readonly [(PL extends LayoutLiteral ? {
    name: "payload";
    binary: "object";
    layout: DynamicItemsOfLayout<LayoutOf<PL>>;
} : {
    name: "payload";
    binary: "bytes";
}) extends infer T_1 ? T_1 extends (PL extends LayoutLiteral ? {
    name: "payload";
    binary: "object";
    layout: DynamicItemsOfLayout<LayoutOf<PL>>;
} : {
    name: "payload";
    binary: "bytes";
}) ? T_1 extends {
    custom: import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType | import("@wormhole-foundation/sdk-base").FixedConversion<import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType, any>;
} ? never : T_1 extends import("@wormhole-foundation/sdk-base").ArrayLayoutItem | import("@wormhole-foundation/sdk-base").ObjectLayoutItem ? DynamicItemsOfLayout<T_1["layout"]> extends readonly LayoutItem[] ? [DynamicItemsOfLayout<T_1["layout"]>[number]] extends [never] ? never : { readonly [K_1 in keyof T_1]: K_1 extends "layout" ? DynamicItemsOfLayout<T_1["layout"]> : T_1[K_1]; } : never : T_1 : never : never]]>) => VAA<PL>;
export declare function registerPayloadType<LL extends LayoutLiteral>(payloadLiteral: LL, payloadLayout: Layout): void;
export declare const serialize: <PL extends PayloadLiteral>(vaa: VAA<PL>) => Uint8Array;
export declare const serializePayload: <PL extends PayloadLiteral>(payloadLiteral: PL, payload: PayloadLiteralToPayloadType<PL>) => Uint8Array;
export type NamedPayloads = readonly (readonly [string, Layout])[];
export declare const payloadDiscriminator: <NP extends NamedPayloads>(namedPayloads: NP) => (data: Uint8Array | string) => [...{ [K in keyof NP]: K extends `${number}` ? NP[K][0] : never; }][number] | null;
export declare function deserialize<PL extends PayloadLiteral>(payloadLiteral: PL, data: Uint8Array | string): VAA<PL>;
export declare function deserialize<LL extends LayoutLiteral>(discriminator: (data: Uint8Array | string) => LL | null, data: Uint8Array | string): VAA<LL>;
export declare function deserializePayload<PL extends PayloadLiteral>(payloadLiteral: PL, data: Uint8Array | string, offset?: number): PayloadLiteralToPayloadType<PL>;
export declare function deserializePayload<LL extends LayoutLiteral>(discriminator: (data: Uint8Array | string) => LL | null, data: Uint8Array | string, offset?: number): [LL, LayoutLiteralToPayloadType<LL>];
export {};
//# sourceMappingURL=vaa.d.ts.map